@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 - 2021
+ * Copyright 2015 - 2022
  * Andr\xe9 Malo or his licensors, as applicable
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
@@ -491,8 +491,13 @@ pl_mmap_buf_new(Py_ssize_t size, PyObject **mmap__, void **target_)
         goto error_mapped;
     }
 
-    *mmap__ = mmap_;
+    tmp = PyObject_CallMethod(tfile, "close", "()");
     Py_DECREF(tfile);
+    if (!tmp)
+        goto error_mmap;
+    Py_DECREF(tmp);
+
+    *mmap__ = mmap_;
     Py_DECREF(m_mmap);
 
     return 0;
@@ -501,6 +506,8 @@ error_mapped:
     Py_DECREF(mmap_);
 
 error_tfile:
+    tmp = PyObject_CallMethod(tfile, "close", "()");
+    Py_XDECREF(tmp);
     Py_DECREF(tfile);
 
 error_mmap:
